*Module 1: Introduction to Stata
version 16.0

import delimited "C:\Users\faela\Downloads\Module_2_Data.csv", encoding(Big5) clear 

help pwd
********************************************************************************
********************************************************************************
********************************************************************************
*Module 2: Working with Data
pwd

cd "C:\Users\faela\Desktop\Statistics Education Training\CIRHT"

*call in data
use Module_2_Data, clear

import delimited "C:\Users\faela\Desktop\Statistics Education Training\CIRHT\Module_2_Data.csv", encoding(Big5) clear 

clear

*enter data manually

********************************************************************************
********************************************************************************
********************************************************************************
*Module 3: Data Management in Stata
 import delimited "C:\Users\faela\Desktop\Statistics Education Training\CIRHT\Module_10_Data.csv", clear
 describe

*label variables
label var salary "Salary in US Dollars for Academic Year"

*Export the data to save

*label values of categorical varaibles
label define rank_lab 1 "assistant" 2 "associate" 3 "full"
label values rank rank_lab

*admire labels
tab rank

*or ignore them
tan rank, nolabel

*to remove labels, don't include label name 
label values rank
*you can also do this through the menu 

*Generate new variables
gen salary__3cat = 1 if salary >= 75000

*stata considers missing values to be larger, so make sure missing values are
*treated as NAs
drop salary__3cat
gen salary_3cat = 1 if salary >= 75000 & salary != .

*use gen to create variable and replace to add values
replace salary_3cat = 2 if salary < 75000 & salary >= 50000
replace salary_3cat = 3 if salary < 50000

*or you can create the variable this way
gen salary_3cat = 1 if salary >= 75000
replace salary_3cat = 2 if salary < 75000 & salary >= 50000
replace salary_3cat = 3 if salary < 50000
replace salary_3cat = . if salary == .

*Generating Dummy variables
gen high_salary = (salary > 50000)
tab high_salary

*deal with missing values
replace high_salary = . if salary == .

*create dummy from existing categorical 
tab rank, gen(rank_dum_)

*use egen to count the number of missing or non-missing values
help egen

*this command will count the number of missing values for each subject
egen nmiss = rowmiss(salary-male)

*use _n, where stata stores the current row number id_n b/c id already a variable
gen id_n = _n

*Recoding missing values
*recoding values to blanks if the missing value is 999
mvdecode salary, mv(999)
*if multiple values codes
mvdecode salary, mv(999 888 777)

*if we want the missing to be characters
replace salary = .a if salary == 999

*to recode blanks as numeric values
mvencode _all, mv(999)

*Sorting Data sets
gsort +salary

*if we wanted to sort by gender and by descending salary within gender
gsort +male salary
list male salary

*Usually we want to sort by id
gsort +id

*Merging Data Sets
use facultysalary_part1.dta, clear
describe
codebook

********************************************************************************
*Merging data sets
*Use the menus to append DTP_append_a and DTP_append_b
*import and save each file as .dta to make merge easier
*open DTP_append_a first, then use menus to append the file
*data - combine datasets - append datasets
import delimited "C:\Users\faela\Desktop\Statistics Education Training\CIRHT\DTP_append_A.csv", encoding(UTF-8) clear 
save "DTP_append_A.dta"

import delimited "C:\Users\faela\Desktop\Statistics Education Training\CIRHT\DTP_append_B.csv", clear
save "DTP_append_B.dta"

use DTP_append_a.dta

*Conveting Long to wide
*converting data formats
use Long_to_Wide.dta, clear

*converting long to wide
reshape wide TestScore, i(id) j(Time)

*converting wide to long
reshape long TestScore, i(id) j(Time)

*Additional Data Management tools
*convert string to numeric, all characters must be numeric for this to work
destring varname, replace

*convert numeric to string 
tostring varname, replace

*check for duplicates
duplicates list
duplicates list subjected

*change the order of the variables
order var1 var2

********************************************************************************
********************************************************************************
********************************************************************************
*Module 4: Statistical Analysis and Graphing in Stata
*Correlation v. Causation
*Parametric v. non-Parametric Tests
*data comes from a underlying normal distribution v. not normal
*We wont talk about non-parametric in this 
********************************************************************************
*Univariate Analysis
import delimited "C:\Users\faela\Desktop\Statistics Education Training\CIRHT\Module_10_Data.csv", clear

*Data-Decscribe data-Describe data contents (codebook)
codebook salary male

*Statistics-Summaries, tables, and tests-Summary and descriptive statistics-Summary *statistics
summarize
summarize salary yearsdg

*detailed summaries can be obtainted by adding ,detail  
summarize salary yearsdg, detail

*statistics- summaries, tables, and tests - summary and descriptive statistics- means
mean salary yearsdg 

********************************************************************************
*Graphing one continuous variable
hist salary

*default is density, to plot freq use freq
hist salary, freq

*the bins represent a collection of values, you can change the # of bins
hist salary, bin(20) normal

*show how to plot with menus

*another way to plot single continuous variable is box plot
graph box salary

*another way to check if a continuous variable is normal is to use qq
*observed salary values on y-axis against the values that would be expected assuming the *variable followed a normal distribution
qnorm salary

*graphics-histogram
*graphics-box plot
*graphics-distributional graphs-normal quantile plots
*you can alter title and axis lables easily in the menus

********************************************************************************
*Univariate statistics for one categorical variable
*statistics-summaries, tables, and tests-tables-one way tables
tab rank
*to get rid of labels
tab rank, nolabel

*to get multiple one way tables
*statistics-summaries, tables, and tests-tables- multiple one way tables
tab1 rank male

*graphing one categorical variable
*create dummy variables for each level and graph the dummy variables
tabulate rank, gen (rank_dum)
graph bar rank_dum1 rank_dum2 rank_dum3

*OR
graph bar rank_dum*

*manually change the axix and title in graph editor
*you can copy/paste graph or export it

********************************************************************************
*Bivariate Analysis 
*Association Between Two Categorical Variables
*statistics - summaries, tables, and tests - Frequency tables - two-way tables with *measures of association
tab rank male

*create label for male
label define male_lab 0 "Female" 1 "Male" 
label values male male_lab

tab rank male

*chi^2 tests the null that the variables are not associated (meaning that the *distribution of faculty ranks for male and female would be the same) the chi is large *and significant p < 0.000, we would conclude faculty and gender are significantly *related in this data

tab rank male, row chi
********************************************************************************
*graphing two categorical variables
*graphics-box plot - mean rank_dum1-3 by male
graph bar rank_dum*, over(male)

*graphing the non dummy gives the total mean of rank and its components
graph bar rank*, over(male)

*Create 2 plots instead of 1 combined in single graph
graph bar rank_dum*, by(male)

********************************************************************************
*Associations between a categorical and a continuous variables
*best way is to calculate summary statistics for the continuous variables separated
*by the categorical variable
mean salary, over(male)

*statistics-summaries, tables, and tests- classical tests of hypotheses- t-test
ttest salary, by(male)
*We usually care about this line of the output
* Ha: diff < 0                 Ha: diff != 0                 Ha: diff > 0
* Pr(T < t) = 0.0000         Pr(|T| > |t|) = 0.0000          Pr(T > t) = 1.0000

*statistics- summaries, tables, and tests - classical tests of hypotheses - variance *comparison test
*check variance
sdtest salary, by(male)

*different variances, so re-run t-test to specify unequal variances
ttest salary, by(male) unequal

*associations between a continuous and categorical with more than 2 groups
oneway salary rank, bonferroni tabulate
*F statistics tells us there is a significant difference
*Bartletts test tells us there is not evidence of unconstant variance, p > 0.05

********************************************************************************
*Graphing associations between one categorical and one continuous variable
hist salary, by(rank) normal

graph box salary, over(rank)

********************************************************************************
*Associations between two continuous variables: correlation
*statistics - summaries, tables, and tests - summary and descriptive statistics -
*correlations and covariances
correlate salary exprior market yearsdg

*if you want p value 
*statistics - summaries, tables, and tests - summary and descriptive statistics - *pairwise correlations
pwcorr salary exprior market yearsdg, sig obs

*Graphing Associations between two continuous variables: correlation
*scatterplots is one of the most used plots
*the menus for twoway can be confusing because you can create different types
*of twoway plots, but you just have to practice and play around with the plots
twoway (scatter salary market)

*add a regression line
twoway (scatter salary market) (lfit salary market)


********************************************************************************
*Associations betwen two continuous variables: paired t-test 
use pulse.dta, clear

*relationship between 2 paired continuous variables (i.e. left v. right eye or before *and after an intervention)
*statistics - summaries, tables, and tests - classical tests of hypotheses - *mean-comparison test, paired data
ttest pulse1 == pulse2

********************************************************************************
*Multiple linear regression
 
import delimited "C:\Users\faela\Desktop\Statistics Education Training\CIRHT\Module_10_Data.csv", clear

*statistics - linear models and related - linear regression
 regress salary market male
 
*graphing data from this models
*go to graphics
*choose twoway
*create plot1
*select appropriate plot
*create plot for male = 0 and male = 1, make sure all other plots are disabled
twoway (scatter salary market if male == 0) (scatter salary market if male == 1)
 
*Change the markers, males are + females are dots
twoway(scatter salary market if male == 0) (scatter salary market if male == 1, msymbol(plus))

*we can also add fit lines by defining plots 3 and 4
*legend harder in menus
twoway(scatter salary market if male == 0, mcolor(blue)) /// 
(scatter salary market if male == 1, mcolor(red) msymbol(plus)) /// 
(lfit salary market if male == 0, lcolor(blue)) /// 
(lfit salary market if male == 1, lcolor(red) lpattern(dash)), /// 
ytitle("Salary") ///
title("Plot of Salary and Marketability by Gender") ///
legend(label(1 "Females") label(2 "Males") label(3 "Female Fit Line") label(4 "Male Fit Line"))

help graph

********************************************************************************
*Using categorical predictors in a regression model 
reg salary market i.rank i.male
*stata will automatically enter the necessary number of dummy variables for the 
*categorical variable into a regression with i.
*by default the smallest value of the categorical variable will be used as the base level
*to select a particular base category for a categorical predictor 
reg salary market ib3.rank i.male

********************************************************************************
*Interaction terms in a regression model
*interaction terms can be added to a regression model in the command line by either
* ## or # between 2 variables. Using ## will automatically include the main effects
*of the two variables, while # will not include the main effects
*categorical predictors are defined by i. while continuous predictors are defined by c.
*Equivalent regressions are groupes below
*interaction between 2 continuous 
reg salary market yearsdg c.market#c.yearsdg
reg salary c.market##c.yearsdg

*interaction between categorical and continuous
reg salary i.male##c.yearsdg
reg salary i.male yearsdg i.male#c.yearsdg

*if we try to run through the menus, it will compare each category with each category
*of the continuous variables

*interaction between 2 categorical variables
reg salary i.rank##i.male
reg salary i.rank i.male i.rank#i.male

*Margins can be run after a model to get the conditional means for each category
*or evaluate the regression for a particular groups or at particular values
margins male, at(rank=(1 2 3))
*the table tells us that a female faculty with rank=1 (assistant professor) is
*expected to earn $37,593.45 based on the previously run models

*A plot is useful in understanding interaction terms
marginsplot

*more insight into the interaction providing all pairwise comparisons between the 
*categories outlined above
margins male, at(rank = (1 2 3 )) pwcompare

********************************************************************************
*Regression Diagnostics
*Assume the residuals follow a normal distribution with mean 0 and constant variances
*the variance of the residuals should be euqal between the levels of the grouping *variables
reg salary i.male i.rank market yearsdg i.male#c.yearsdg

*to check the normality of the residuals we can use a QQplot
*first we must save the residuals
predict resid, rstandard

*we can also use the menus statistics- postestimation - predictions, residuals, etc
*now we can plot the residuals with either QQ plot or histogram
qnorm resid
qnorm resid if male == 0 & rank == 1
qnorm resid if male == 1 & rank == 1

*statistics - summaries, tables, and tests - distributional plots and tests - 
*normal quantile plot

*Stata makes some diagnostic plots available immedately after an etimation command
*one useful plot is the residual v. fitted plot
*this plot can be used to check that the residuals have a mean of 0 and constant variance
rvfplot

*statistics - linear models and related - regression diagnostics - resitual v fitted
*look at the plot, it appears the fitted values increase and so do the residuals
*this violates constant variances
*a plot should look completly random
*in this case a transformation of Y such as log(Y) may help meet the assumption

*there is also a formal test of homogeneity (constant variance) or heteroskedasticity
*(non-constant variance)
estat hettest

*the test is significant which indicates heteroskedasticity
*statistics - linear models and related - regression diagnostics - specification tests

*we can also check the variance of the residuals with a boxplot
graph box resid, over(rank)
graph box resid, over(male)

*we can also use a formal tests
sdtest resid, by(male)
*the test is significant which indicates a significant difference in variance (bad)
*statistics - summaries, tables, and tests - classical tests of hypotheses - two group
*variance comparison test

********************************************************************************
*Multiple logistic regression
*logit dummyvar pred1 pred2 pred3...
*suppose we want to predict whether or not a faculty members salary would be 
*greater than $50,000 per year
gen Salary_cat = 1 if salary > 50000 &salary != .
replace Salary_cat = 0 if salary <= 50000
label define Salary_cat 1 "Salary > 50000" 0 "Salary <= 50000"
label values Salary_cat Salary_cat
tab Salary_cat
logit Salary_cat male market

*the option or can request the estimated coefficients to be odds ratios
logit Salary_cat male market, or

*if predictors include categorical variables, the same rules apply about cat predictors
logit Salary_cat i.male market, or

*the reference category can be switched to male (interpret coefficient for females)
logit Salary_cat ib1.male market, or

********************************************************************************
*Analyzing Subsets of Data
correlated salary exprior market if male == 1

reg salary yearsdg if male == 1 & (rank == 2 | rank == 3)

*Performing stratified analyses for all groups
*Instead of performing analyses on subsets of a data set, many data analysts are often interested in performing the same analysis on all possible subsets of a data set defined by a grouping variable.
gsort +male
by male: correlate salary yearsdg market

*first the data set needs to be sorted by the grouping variable (male) then the stratified analysis can be performed by typing male: in frot of the analysis command and Stata will output the correlations for both male and female faculty members
by male: correlate salary yearsdg market if rank == 3
bysort male: correlate salary yearsdg market

*Working with complex sample survey data
svyset psuvar [pweight = weightvar], strata(stratavar)

*svyset defines the variables indentifying the complex design of the sample to Stata, and only needs to be submitted once in a given Stata session. The psuvar is a variable identifying the primary sampling unit that an observtion came from. weightvar is a variable containing sample weight. 